==> cmrf_reference-1.0.8.tar.gz: cmrf_reference/src/Element/CMRFReference.php <==
<?php
/**
 * @author Klaas Eikelboom  <klaas.eikelboom@civicoop.org>
 * @date 16-May-2020
 * @license  AGPL-3.0
 */
namespace Drupal\cmrf_reference\Element;

use Drupal\cmrf_reference\CMRFReferenceUtils;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Annotation\FormElement;
use Drupal\Core\Render\Element\Textfield;

/**
 * Provides a lookup using CiviMRF
 *
 * @FormElement("cmrf_reference")
 */
class CMRFReference extends Textfield {

  /**
   * {@inheritdoc}
   */
  public function getInfo() {
    $class = get_class($this);
    $info = parent::getInfo();
    // maxlength leads to validation errors with multi-value fields.
    unset($info['#maxlength']);
    $info['#pre_render'][] = [$class, 'preRenderCMRFReference'];
    $info['#theme'] = 'select';
    //$info['#theme_wrappers'] = 'form_element';
    $info['#process'] []= [$class, 'removeOptions'];
    return $info;
   }

  /**
   * {@inheritDoc}
   */
   public static function valueCallback(&$element, $input, FormStateInterface $form_state) {
    if (is_array($input)) {
      $return = [];
      foreach ($input as $key => $value) {
        $return[$key] = parent::valueCallback($element, $value, $form_state);
      }
    }
    else {
      $return = parent::valueCallback($element, $input, $form_state);
    }
    return $return;
  }

  /**
   * Generete the css class for the jquery element to act on
   *
   * @param $element
   *
   * @return mixed
   */
  public static function preRenderCMRFReference($element) {
    static::setAttributes($element, ['js-webform-cmrf-reference']);
    if (isset($element['#default_value'])) {
      $values = !is_array($element['#default_value']) ? [$element['#default_value']] : $element['#default_value'];
      $defaults = [];
      foreach ($values as $value) {
        $defaults[$value] = CMRFReferenceUtils::lookup($element['#cmrf_connection'],
          $element['#dataprocessor'],
          $element['#cmrf_display'],
          $value,
          $element['#cmrf_default_filter']
        );
      }
      $element['#attached']['drupalSettings']['cmrf_reference']['defaults'][$element["#webform_key"]] = $defaults;
    }

    if (isset($element["#cmrf_extra_filter"]) && $element["#cmrf_extra_filter"] != CMRFReferenceUtils::NONE) {
      $element['#attached']['drupalSettings']['cmrf_reference']['extra_filter_value'][$element["#webform_key"]] = \Drupal::token()
        ->replacePlain($element['#cmrf_extra_filter_value']);
    }

    return $element;
  }

  /**
   * This function is activated by adding the [#process] field toe the getinfo
   *
   * @param $element
   *
   * @return mixed
   */
  public static function removeOptions($element) {
    // deep inside the drupal forms validator is a check that when a fields
    // has options - the resulting value must be one of this options
    // by removing this element - this check is circumvented.
    unset($element['#options']);
    return $element;
  }

}

==> cmrf_reference-1.0.9.tar.gz: cmrf_reference/src/Element/CMRFReference.php <==
<?php
/**
 * @author Klaas Eikelboom  <klaas.eikelboom@civicoop.org>
 * @date 16-May-2020
 * @license  AGPL-3.0
 */
namespace Drupal\cmrf_reference\Element;

use Drupal\cmrf_reference\CMRFReferenceUtils;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Annotation\FormElement;
use Drupal\Core\Render\Element\Textfield;

/**
 * Provides a lookup using CiviMRF
 *
 * @FormElement("cmrf_reference")
 */
class CMRFReference extends Textfield {

  /**
   * {@inheritdoc}
   */
  public function getInfo() {
    $class = get_class($this);
    $info = parent::getInfo();
    // maxlength leads to validation errors with multi-value fields.
    unset($info['#maxlength']);
    $info['#pre_render'][] = [$class, 'preRenderCMRFReference'];
    $info['#theme'] = 'select';
    //$info['#theme_wrappers'] = 'form_element';
    $info['#process'] []= [$class, 'removeOptions'];
    return $info;
   }

  /**
   * {@inheritDoc}
   */
   public static function valueCallback(&$element, $input, FormStateInterface $form_state) {
    if (is_array($input)) {
      $return = [];
      foreach ($input as $key => $value) {
        $return[$key] = parent::valueCallback($element, $value, $form_state);
      }
    }
    else {
      $return = parent::valueCallback($element, $input, $form_state);
    }
    return $return;
  }

  /**
   * Generete the css class for the jquery element to act on
   *
   * @param $element
   *
   * @return mixed
   */
  public static function preRenderCMRFReference($element) {
    static::setAttributes($element, ['js-webform-cmrf-reference']);
    $extraFilterValue = \Drupal::token()->replacePlain($element['#cmrf_extra_filter_value']);
    if (isset($element['#default_value'])) {
      $values = !is_array($element['#default_value']) ? [$element['#default_value']] : $element['#default_value'];
      $defaults = [];
      foreach ($values as $value) {
        $defaults[$value] = CMRFReferenceUtils::lookup($element['#cmrf_connection'],
          $element['#dataprocessor'],
          $element['#cmrf_display'],
          $value,
          $element['#cmrf_default_filter'],
          $element['#cmrf_extra_filter'],
          $extraFilterValue
        );
      }
      $element['#attached']['drupalSettings']['cmrf_reference']['defaults'][$element["#webform_key"]] = $defaults;
    }

    if (isset($element["#cmrf_extra_filter"]) && $element["#cmrf_extra_filter"] != CMRFReferenceUtils::NONE) {
      $element['#attached']['drupalSettings']['cmrf_reference']['extra_filter_value'][$element["#webform_key"]] = $extraFilterValue;
    }

    return $element;
  }

  /**
   * This function is activated by adding the [#process] field toe the getinfo
   *
   * @param $element
   *
   * @return mixed
   */
  public static function removeOptions($element) {
    // deep inside the drupal forms validator is a check that when a fields
    // has options - the resulting value must be one of this options
    // by removing this element - this check is circumvented.
    unset($element['#options']);
    return $element;
  }

}
